/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
 *                         University of Stuttgart.  All rights reserved.
 * $COPYRIGHT$
 * 
 * Additional copyrights may follow
 * 
 * $HEADER$
 */
/**
 *  @file 
 */

#ifndef MCA_PML_OB1_COMPONENT_H
#define MCA_PML_OB1_COMPONENT_H

#if defined(c_plusplus) || defined(__cplusplus)
extern "C" {
#endif

/*
 * PML module functions.
 */
OMPI_MODULE_DECLSPEC extern mca_pml_base_component_2_0_0_t mca_pml_ob1_component;

#if defined(c_plusplus) || defined(__cplusplus)
}
#endif

#endif
